@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Chromatic and diatonic musical ornamentation
 
-our $VERSION = '0.0202';
+our $VERSION = '0.0203';
 
 use Carp qw(croak);
 use Data::Dumper::Compact qw(ddc);
@@ -61,6 +61,8 @@ has verbose => (
 sub grace_note {
     my ($self, $duration, $pitch, $offset) = @_;
 
+    $offset //= 1;
+
     my $grace_note;
     if ($self->scale_name eq 'chromatic') {
         my $note = Music::Note->new($pitch, 'ISO')->format('midinum') + $offset;
@@ -84,7 +86,7 @@ sub grace_note {
 sub turn {
     my ($self, $duration, $pitch, $offset) = @_;
 
-    $offset ||= 1;
+    $offset //= 1;
 
     my ($above, $below);
 
@@ -117,7 +119,7 @@ sub trill {
     my ($self, $duration, $pitch, $number, $offset) = @_;
 
     $number ||= 4;
-    $offset ||= 1;
+    $offset //= 1;
 
     my $alt;
 
@@ -147,7 +149,7 @@ sub trill {
 sub mordent {
     my ($self, $duration, $pitch, $offset) = @_;
 
-    $offset ||= 1;
+    $offset //= 1;
 
     my $alt;
 
@@ -190,7 +192,7 @@ Music::MelodicDevice::Ornamentation - Chromatic and diatonic musical ornamentati
 
 =head1 VERSION
 
-version 0.0202
+version 0.0203
 
 =head1 SYNOPSIS
 
@@ -240,6 +242,8 @@ Please see L<Music::Scales/SCALES> for a list of valid scale names.
 
 Default: C<0>
 
+Show the progress of the methods.
+
 =head1 METHODS
 
 =head2 new
@@ -256,6 +260,8 @@ Create a new C<Music::MelodicDevice::Ornamentation> object.
 
   $spec = $md->grace_note($duration, $pitch, $offset);
 
+Default offset: C<1>
+
 "Appoggiatura" means emphasis on the grace note.  "Acciaccatura" means
 emphasis on the main note.  This module doesn't accent notes.  You'll
 have to do that bit.
@@ -278,6 +284,10 @@ A trill is a B<number> of pairs of notes spread over a given
 B<duration>.  The first of the pair being the given B<pitch> and the
 second one given by the B<offset>.
 
+Default number: C<4>
+
+Default offset: C<1>
+
 =head2 mordent
 
   $spec = $md->mordent($duration, $pitch, $offset);
